summaryrefslogtreecommitdiffstats
path: root/kmail/kmfoldermaildir.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kmail/kmfoldermaildir.cpp')
-rw-r--r--kmail/kmfoldermaildir.cpp12
1 files changed, 6 insertions, 6 deletions
diff --git a/kmail/kmfoldermaildir.cpp b/kmail/kmfoldermaildir.cpp
index c12a5891..c6fa7be2 100644
--- a/kmail/kmfoldermaildir.cpp
+++ b/kmail/kmfoldermaildir.cpp
@@ -1012,7 +1012,7 @@ static bool removeDirAndContentsRecursively( const TQString & path )
//-----------------------------------------------------------------------------
int KMFolderMaildir::removeContents()
{
// NOTE: Don' use KIO::netaccess, it has reentrancy problems and multiple
// mailchecks going on trigger them, when removing dirs
if ( !removeDirAndContentsRecursively( location() + "/new/" ) ) return 1;
if ( !removeDirAndContentsRecursively( location() + "/cur/" ) ) return 1;
@@ -1132,14 +1132,14 @@ TQ_INT64 KMFolderMaildir::doFolderSize() const
//kdDebug(5006) << k_funcinfo << "Starting dirSizeJob for folder "
// << location() << endl;
KDirSize* job = KDirSize::dirSizeJob( list );
- connect( job, TQT_SIGNAL( result( KIO::Job* ) ),
- this, TQT_SLOT( slotDirSizeJobResult( KIO::Job* ) ) );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
+ this, TQT_SLOT( slotDirSizeJobResult( TDEIO::Job* ) ) );
}
return -1;
}
-void KMFolderMaildir::slotDirSizeJobResult( KIO::Job* job )
+void KMFolderMaildir::slotDirSizeJobResult( TDEIO::Job* job )
{
mCurrentlyCheckingFolderSize = false;
KDirSize * dirsize = dynamic_cast<KDirSize*>( job );
@@ -1164,8 +1164,8 @@ void KMFolderMaildir::slotDirSizeJobResult( KIO::Job* job )
//kdDebug(5006) << k_funcinfo << "Starting dirSizeJob for folder "
// << entry.first->location() << endl;
KDirSize* job = KDirSize::dirSizeJob( entry.second );
- connect( job, TQT_SIGNAL( result( KIO::Job* ) ),
- entry.first, TQT_SLOT( slotDirSizeJobResult( KIO::Job* ) ) );
+ connect( job, TQT_SIGNAL( result( TDEIO::Job* ) ),
+ entry.first, TQT_SLOT( slotDirSizeJobResult( TDEIO::Job* ) ) );
break;
}
else
@@ -1012,7 +1012,7 @@ static bool removeDirAndContentsRecursively( const TQString & path )
int KMFolderMaildir::removeContents()
{
- // NOTE: Don' use KIO::netaccess, it has reentrancy problems and multiple
+ // NOTE: Don' use TDEIO::netaccess, it has reentrancy problems and multiple
// mailchecks going on trigger them, when removing dirs
if ( !removeDirAndContentsRecursively( location() + "/new/" ) ) return 1;